## Replication file for main results of "The Global Diffusion of Environmental Clubs:
## The Chemical Industry's Responsible Care" by Ellen Holtmaat, Christopher Adolph,
## and Aseem Prakash
##
## Christopher Adolph   http://faculty.washington.edu/cadolph
## 17 December 2018

## Clear memory
rm(list=ls())

## Set base directory
basedir <- getwd()

## Load libraries
library(MASS)         # For mvrnorm()
library(survival)     # For Cox ph and simulation
library(tile)         # Data visualization; installable from included package archives
library(simcf)        # For extractdata() and lagpanel();
                      # installable from included package archives
library(RColorBrewer) # Color selection
helper <- paste(basedir,"helper.R",sep="/") 
source(helper)        # Helper functions for this project: makeplags() and simCoxPH() 

## Set up colors
col <- brewer.pal(7, "Set1")
nicered <- col[1]
niceblue <- col[2]
nicegreen <- col[3]
nicepurple <- col[4]
niceorange <- col[5]
nicebrown <- col[7]

## Preliminaries
sims <- 1000000

## Load main data 
dataALL <- read.csv(paste(basedir, "finalDataV1.csv", sep="/"))

## Process data

## Create "new country" variable
dataALL$newcountry <- -1*(dataALL$independence - 1)

## Create combined US & EU export %
dataALL$pctUSEUexports <- dataALL$pctEUexports + dataALL$pctUSexports

## Remove Arabian states (not iid)
arabianStates <- c("Saudi Arabia", "Kuwait", "United Arab Emirates",
                   "Qatar", "Oman", "Bahrain")
arabianIDX <- rep(NA, nrow(dataALL))
for (i in 1:nrow(dataALL)) {
    arabianIDX[i] <- any(dataALL$country[i]==arabianStates)
}
data <- dataALL[!arabianIDX,]


## Estimate baseline model using Cox Proportional Hazards

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports + pctOECDexports + pctWorldExports + pctNonmemberExports + pctRCnbhood500 + newcountry + treatiesZ1980 + ENGOs + fdigdp + polity2 + gdppc + gdp
mdata <- extractdata(model, data, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata1a <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata1a$year-1, time2=mdata1a$year, event=mdata1a$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model1a <- survdata ~ pctRCexportsL1 + pctOECDexportsL1 + pctWorldExportsL1  + pctRCnbhood500L1 + newcountryL1 + treatiesZ1980L1 + ENGOs + fdigdpL1 + polity2L1 + log(gdppcL1) + log(gdpL1) + cluster(country)

## Estimate CPH model
res1a <- coxph(model1a, data=mdata1a, x=TRUE, y=TRUE)
summary(res1a)

## Check proportional hazards assumption
cox.zph(res1a)

## Simulate from this model to produce substantively relevant hazards
## for continuous covariates

## Rename model data
mdataS <- na.omit(mdata1a)
res <- res1a

## Simulate coefficients to account for estimation uncertainty
simbetas <- exp(mvrnorm(sims, coef(res), vcov(res)))

## Collect counterfactual changes for each covariate:
## typically IQR range for continuous covariates
## and 0 to 1 change for binary covariates
CFnames <- CFs <- NULL

CFnames <- c(CFnames, "More chemical exports to RC members")
CFs <- rbind(CFs, simCoxPH(simbetas[,1], quantile(mdataS$pctRCexports, probs=0.25),
                           quantile(mdataS$pctRCexports, probs=0.75),
                           0))

CFbaseline <- simCoxPH(simbetas[,1], quantile(mdataS$pctRCexports, probs=0.25),
                           quantile(mdataS$pctRCexports, probs=0.75),
                           0)
             
CFnames <- c(CFnames, "More chemical exports to OECD")
CFs <- rbind(CFs, simCoxPH(simbetas[,2], quantile(mdataS$pctOECDexports, probs=0.25),
                           quantile(mdataS$pctOECDexports, probs=0.75),
                           0))
         
CFnames <- c(CFnames, "More total chemical exports")
CFs <- rbind(CFs, simCoxPH(simbetas[,3], quantile(mdataS$pctWorldExports, probs=0.25),
                           quantile(mdataS$pctWorldExports, probs=0.75),
                           0))

CFnames <- c(CFnames, "More RC member neighbors")
CFs <- rbind(CFs, simCoxPH(simbetas[,4], quantile(mdataS$pctRCnbhood500, probs=0.25),
                           quantile(mdataS$pctRCnbhood500, probs=0.75),
                           0))

CFnames <- c(CFnames, "Country established after RC founded")
CFs <- rbind(CFs, simCoxPH(simbetas[,5], 0, 1, 0))

CFnames <- c(CFnames, "More environmental treaties ratified")
CFs <- rbind(CFs, simCoxPH(simbetas[,6], quantile(mdataS$treatiesZ1980, probs=0.25),
                           quantile(mdataS$treatiesZ1980, probs=0.75),
                           0))

CFnames <- c(CFnames, "More environmental NGOs")
CFs <- rbind(CFs, simCoxPH(simbetas[,7], quantile(mdataS$ENGOs, probs=0.25),
                           quantile(mdataS$ENGOs, probs=0.75),
                           0))
             
CFnames <- c(CFnames, "Higher inward FDI/GDP")
CFs <- rbind(CFs, simCoxPH(simbetas[,8], quantile(mdataS$fdigdp, probs=0.25),
                           quantile(mdataS$fdigdp, probs=0.75),
                           0))

CFnames <- c(CFnames, "More democratic")
CFs <- rbind(CFs, simCoxPH(simbetas[,9], quantile(mdataS$polity2, probs=0.25),
                           quantile(mdataS$polity2, probs=0.75),
                           0))

CFnames <- c(CFnames, "Higher economic development")
CFs <- rbind(CFs, simCoxPH(simbetas[,10], log(quantile(mdataS$gdppc, probs=0.25)),
                           log(quantile(mdataS$gdppc, probs=0.75)),
                           0))

CFnames <- c(CFnames, "Larger economy")
CFs <- rbind(CFs, simCoxPH(simbetas[,11], log(quantile(mdataS$gdp, probs=0.25)),
                           log(quantile(mdataS$gdp, probs=0.75)),
                           0))

## Sort results by effect size for better plotting
sortedCFnames <- CFnames[rev(order(CFs[,1]))]
sortedCFs <- CFs[rev(order(CFs[,1])),]


## Plot all results with ropeladder from tile package

## Main trace of simulation results
trace1c <- ropeladder(x = sortedCFs[,1],
                      lower = sortedCFs[,2],
                      upper = sortedCFs[,3],
                      labels = sortedCFnames,
                      entryheight=0.2,
                      pch=c(15, rep(16, length(sortedCFs)-1)),
                      col=niceblue,
                      size=0.725,
                      lex=1.75,
                      lineend="square",
                      plot=1
                      )

## Mark statistically significant results
sigMark1 <- sortedCFs[,1]
is.na(sigMark1) <- ((sortedCFs[,2]-1)*(sortedCFs[,3]-1)) > 0
traceSig1 <- ropeladder(x=sigMark1,
                        col="white",
                        pch=c(15, rep(16, length(sortedCFs)-1)),
                        group=1,
                        plot=1)

## Add reference line at 1.0
vertmark <- linesTile(x=c(1,1), y=c(0,1), layer=12, plot=1)

## Set plot limits
limits <- c(0.40, 23)

## Make Figure 3 (differs only from paper in font)
file <- "Figure3"
tile(trace1c, vertmark, traceSig1,
     limits=limits,
     gridlines=list(type="xt"),
     topaxis=list(add=TRUE, log=TRUE, at=c(0.5, 1, 2, 5, 10, 20),
         labels=c("0.5x", "1x", "2x", "5x", "10x", "20x")),
     xaxis=list(log=TRUE, at=c(0.5, 1, 2, 5, 10, 20),
         labels=c("0.5x", "1x", "2x", "5x", "10x", "20x")),
     topaxistitle=list(labels="relative risk of joining Responsible Care", y=0.8),
     width=list(plot=2),
     height=list(topaxistitle=2),
     output=list(outfile=file,width=7.0)
     )
    

############

## Perform robustness checks and save key results for robustness plot

## Set up storage of robustness results
robustnessLabels <- robustnessCFs <- NULL

## Robustness check 1: Bivariate model

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports
mdata <- extractdata(model, data, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata0 <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata0$year-1, time2=mdata0$year, event=mdata0$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model0 <- survdata ~ pctRCexportsL1 + cluster(country)

## Estimate CPH model
res0 <- coxph(model0, data=mdata0, x=TRUE, y=TRUE)
summary(res0)

## Check proportional hazards assumption
cox.zph(res0)

## Simulate parameters
mdataS <- na.omit(mdata0)
simbetas <- exp(mvrnorm(sims, coef(res0), vcov(res0)))

## Compute counterfactual California effect
robustnessLabels <- c(robustnessLabels, "Bivariate Model")
robustnessCFs <- rbind(robustnessCFs, simCoxPH(simbetas[,1],
                                               quantile(mdataS$pctRCexports, probs=0.25),
                                               quantile(mdataS$pctRCexports, probs=0.75),
                                               0))


## Insert Baseline result for comparison
robustnessLabels <- c(robustnessLabels, "Baseline Model")
robustnessCFs <- rbind(robustnessCFs, CFbaseline)


## Robustness Check 2: Baseline plus Exports to US & EU

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports + pctUSEUexports + pctWorldExports + pctNonmemberExports + pctRCnbhood500 + newcountry + treatiesZ1980 + ENGOs + fdigdp + polity2 + gdppc + gdp
mdata <- extractdata(model, data, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata1b <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata1b$year-1, time2=mdata1b$year, event=mdata1b$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model1b <- survdata ~ pctRCexportsL1 + pctUSEUexportsL1 + pctWorldExportsL1  + pctRCnbhood500L1 + newcountryL1 + treatiesZ1980L1 + ENGOs + fdigdpL1 + polity2L1 + log(gdppcL1) + log(gdpL1) + cluster(country)

## Estimate CPH model
res1b <- coxph(model1b, data=mdata1b, x=TRUE, y=TRUE)
summary(res1b)

## Check proportional hazards assumption
cox.zph(res1b)

## Simulate parameters
mdataS <- na.omit(mdata1b)
simbetas <- exp(mvrnorm(sims, coef(res1b), vcov(res1b)))

## Compute counterfactual California effect
robustnessLabels <- c(robustnessLabels, "Baseline + Exports to US & EU")
robustnessCFs <- rbind(robustnessCFs, simCoxPH(simbetas[,1],
                                               quantile(mdataS$pctRCexports, probs=0.25),
                                               quantile(mdataS$pctRCexports, probs=0.75),
                                               0))


## Robustness check 3: Baseline + Arabian Gulf Members

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports + pctOECDexports + pctWorldExports + pctNonmemberExports + pctRCnbhood500 + newcountry + treatiesZ1980 + ENGOs + fdigdp + polity2 + gdppc + gdp
mdata <- extractdata(model, dataALL, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata1c <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata1c$year-1, time2=mdata1c$year, event=mdata1c$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model1c <- survdata ~ pctRCexportsL1 + pctOECDexportsL1 + pctWorldExportsL1  + pctRCnbhood500L1 + newcountryL1 + treatiesZ1980L1 + ENGOs + fdigdpL1 + polity2L1 + log(gdppcL1) + log(gdpL1) + cluster(country)

## Estimate CPH model
res1c <- coxph(model1c, data=mdata1c, x=TRUE, y=TRUE)
summary(res1c)

## Check proportional hazards assumption
cox.zph(res1c)

## Simulate parameters
mdataS <- na.omit(mdata1c)
simbetas <- exp(mvrnorm(sims, coef(res1c), vcov(res1c)))

## Compute counterfactual California effect
robustnessLabels <- c(robustnessLabels, "Baseline + Arabian Gulf Members")
robustnessCFs <- rbind(robustnessCFs, simCoxPH(simbetas[,1],
                                               quantile(mdataS$pctRCexports, probs=0.25),
                                               quantile(mdataS$pctRCexports, probs=0.75),
                                               0))


## Robustness Check 4: Baseline + Civil Society

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports + pctOECDexports + pctWorldExports + pctNonmemberExports + pctRCnbhood500 + newcountry + treatiesZ1980 + ENGOs + fdigdp + civsociety + gdppc + gdp
mdata <- extractdata(model, data, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata1d <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata1d$year-1, time2=mdata1d$year, event=mdata1d$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model1d <- survdata ~ pctRCexportsL1 + pctOECDexportsL1 + pctWorldExportsL1  + pctRCnbhood500L1 + newcountryL1 + treatiesZ1980L1 + ENGOs + fdigdpL1 + civsocietyL1 + log(gdppcL1) + log(gdpL1) + cluster(country)

## Estimate CPH model
res1d <- coxph(model1d, data=mdata1d, x=TRUE, y=TRUE)
summary(res1d)

## Check proportional hazards assumption
cox.zph(res1d)

## Simulate parameters
mdataS <- na.omit(mdata1d)
simbetas <- exp(mvrnorm(sims, coef(res1d), vcov(res1d)))

## Compute counterfactual California effect
robustnessLabels <- c(robustnessLabels, "Baseline + Civil Society")
robustnessCFs <- rbind(robustnessCFs, simCoxPH(simbetas[,1],
                                               quantile(mdataS$pctRCexports, probs=0.25),
                                               quantile(mdataS$pctRCexports, probs=0.75),
                                               0))



## Baseline + Linguistic Similarity

## Extract relevant covariates for this model from main dataset 
model <- RCmember ~ pctRCexports + pctOECDexports + pctWorldExports + pctNonmemberExports + pctRCnbhood500 + newcountry + treatiesZ1980 + ENGOs + fdigdp + polity2 + gdppc + gdp + pctLanguageInRC
mdata <- extractdata(model, data, extra=~country+year, na.rm=FALSE)

## Create one-year lags of all RHS variables
mdata1e <- cbind(mdata, makeplags(model, mdata, "country", "year", lags=1))

## Set up counting process version of time-to-event data
survdata <- Surv(time=mdata1e$year-1, time2=mdata1e$year, event=mdata1e$RCmember)

## Set up final model specification, with clustering, log transf and lags as appropriate
model1e <- survdata ~ pctRCexportsL1 + pctOECDexportsL1 + pctWorldExportsL1  + pctRCnbhood500L1 + newcountryL1 + treatiesZ1980L1 + ENGOs + fdigdpL1 + polity2L1 + log(gdppcL1) + log(gdpL1) + pctLanguageInRCL1 + cluster(country)

## Estimate CPH model
res1e <- coxph(model1e, data=mdata1e, x=TRUE, y=TRUE)
summary(res1e)

## Check proportional hazards assumption
cox.zph(res1e)

## Simulate parameters
mdataS <- na.omit(mdata1e)
simbetas <- exp(mvrnorm(sims, coef(res1e), vcov(res1e)))

## Compute counterfactual California effect
robustnessLabels <- c(robustnessLabels, "Baseline + Linguistic Similarity")
robustnessCFs <- rbind(robustnessCFs, simCoxPH(simbetas[,1],
                                               quantile(mdataS$pctRCexports, probs=0.25),
                                               quantile(mdataS$pctRCexports, probs=0.75),
                                               0))

## Plot robustness checks using tile

## Main trace of simulation results
trace1c <- ropeladder(x = robustnessCFs[,1],
                      lower = robustnessCFs[,2],
                      upper = robustnessCFs[,3],
                      labels = robustnessLabels,
                      entryheight=0.25,
                      col=c(nicepurple, niceblue, rep(nicepurple, length(robustnessCFs)-2)),
                      pch=15,
                      shadowbox=brewer.pal(4, "Pastel1")[4],
                      size=0.725,
                      lex=1.75,
                      lineend="square",
                      plot=1
                      )

## Mark statistically significant results
sigMark1 <- robustnessCFs[,1]
is.na(sigMark1) <- ((robustnessCFs[,2]-1)*(robustnessCFs[,3]-1)) > 0
traceSig1 <- ropeladder(x=sigMark1,
                        col="white",
                        pch=15,
                        group=1,
                        plot=1)

## Add reference line at 1.0
vertmark <- linesTile(x=c(1,1), y=c(0,1), layer=12, plot=1)

## Add text label
textLab <- textTile(labels="Effect of more chemical\nexports to RC members in...",
                    x=0.07,
                    y=1.15,
                    cex=1,
                    clip="off",
                    fontface="italic",
                    plot=1)

## Set plot limits -- should match Figure 3 above
limits <- c(0.40, 23)

## Make Figure 4 (differs only from paper in font)
file <- "Figure4"
tile(trace1c, vertmark, traceSig1, textLab,
     limits=limits,
     gridlines=list(type="xt"),
     topaxis=list(add=TRUE, log=TRUE, at=c(0.5, 1, 2, 5, 10, 20),
         labels=c("0.5x", "1x", "2x", "5x", "10x", "20x")),
     xaxis=list(log=TRUE, at=c(0.5, 1, 2, 5, 10, 20),
         labels=c("0.5x", "1x", "2x", "5x", "10x", "20x")),
     xaxistitle=list(labels="relative risk of joining Responsible Care", y=0.2),
     width=list(plot=2),
     height=list(xaxistitle=2),
     output=list(outfile=file, width=7.0)
     )
    

